class PackagesController < ApplicationController
  protect_with(Component.name, Component.display_name, [RxModule::Authorization.verb("install", "Install", :install)])
  before_action :set_targets
  before_action :set_target, only: :package

  def package
    render json: @model
  end

  def packages
    render json: @models
  end

  def install
    component = RxModuleComponent.create(install_params)
    ComponentInstallJob.perform_later(component)
    render json: component
  end

  private

  def set_targets
    if RxModuleComponent.update_server
      begin
        if RxModuleComponent.update_server
          url = "#{RxModuleComponent.update_server}/packages"
          url += "?prerelease=true" if ENV["ALLOW_PRERELEASE"]
          resp = Faraday.get(url, {}, "Accept" => "application/json")
          Rails.logger.debug { {action: "Package Check", package_server_resp: resp, body: resp.body} }
          @models = JSON.parse(resp.body)
        else
          @models = {}
          Rails.logger.warn { {action: "Package Check", msg: "No update server configured", server: RxModuleComponent.update_server} }
        end
      rescue => err
        @models = {}
        Rails.logger.warn { {action: "Package Check", msg: "Could not reach update server or response malformatted", server: RxModuleComponent.update_server} }
      end
    else
      @models = {}
    end
    @models = @models.map do |code, versions|
      {
        id: code,
        versions: versions,
        installable: RxModuleComponent.module_installable?(code)
      }
    end
    @models
  end

  def set_target
    @model = @models.find { |m| m[:id] === lookup_params[:id] }
    @model
  end

  def install_params
    unwrapped = params.require(:rx_module_package)
    unwrapped.require(:port)
    hub_ip = Component.ensure_self.ip_address
    unwrapped[:module_id] = params.permit(:id)[:id]
    unwrapped[:ip_address] = hub_ip
    unwrapped[:is_updating] = true
    unwrapped.permit(:port, :module_id, :ip_address, :is_updating)
  end

  def lookup_params
    params.permit(:id)
  end

  def applicable_authorization
    return unless authorizations
    @_auth ||= authorizations[:actions].find do |verb|
      if verb[:controller_methods].is_a? Array
        verb[:controller_methods].any? { |method| method.to_s == params["action"].to_s }
      else
        verb[:controller_methods].to_s == params["action"].to_s
      end
    end
  end
end
