import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField, ModelForm, ModelInput} from "@rx-suite/ui";
import {RecurrenceRule} from "./RecurrenceRule";
import {ShiftModel} from "../../stores/ShiftStore";
import {t, Trans} from "@lingui/macro";
import {Add} from "@material-ui/icons";
import {ShiftColorPicker} from "./ShiftColorPicker";
import {Grid, Typography} from "@material-ui/core";
import {PaddedPaper} from "@rx-suite/ui/build";
import {PreviewCalendar} from "./recurrence_rule/PreviewCalendar";
import {CalendarConfigStore} from "../../stores/CalendarConfigStore";

export const ShiftForm: React.FunctionComponent<{ model: ShiftModel, readOnly?: boolean }> = observer(({
                                                                                                           model,
                                                                                                           readOnly
                                                                                                       }) => {
    const hasSchedules = (model.viewModel.shift_schedules && model.viewModel.shift_schedules.length > 0);
    return (
        <>
            <ModelForm model={model} readOnly={readOnly} suppressImportExport>
                <ModelInput name={"name"}/>
                <ShiftColorPicker model={model} readOnly={readOnly}/>
                {!readOnly &&
                <div><ButtonField text={t`Add Schedule Rule`} startIcon={<Add/>} onClick={model.addSchedule}/></div>}
                <Grid container spacing={2}>
                    {
                        hasSchedules ?
                            model.viewModel.shift_schedules.map((schedule, i) => {
                                return <Grid item xs={12} key={schedule.id || i}>
                                    <RecurrenceRule shift={model as ShiftModel} schedule={schedule} scheduleIndex={i}
                                                    readOnly={readOnly}/>
                                </Grid>
                            })
                            : <Grid item xs={12}>
                                <PaddedPaper>
                                    <Typography><Trans>Shift has no scheduled occurrences</Trans></Typography>
                                </PaddedPaper>
                            </Grid>
                    }
                    {hasSchedules && <Grid item xs={12}>
                        <PaddedPaper>
                            <div style={{
                                width: '100%',
                                minHeight: (60 + (((CalendarConfigStore.selectedModel?.span as number) || 12) * 50)),
                                display: 'flex',
                                flexDirection: 'column'
                            }}>
                                <PreviewCalendar model={model}/>
                            </div>
                        </PaddedPaper>
                    </Grid>}
                </Grid>

            </ModelForm>
        </>
    );
});