import * as React from "react";
import {observer} from "mobx-react-lite";
import {BreadModel, makeColumn} from "@rx-suite/ui";
import {ShiftModel, ShiftStore} from "../../stores/ShiftStore";
import {ShiftForm} from "./ShiftForm";
import {t} from "@lingui/macro";
import {Observer} from "mobx-react-lite/";
import {ShiftColorPicker} from "./ShiftColorPicker";

export const ShiftsBreadModel: React.FunctionComponent = observer(() => {
    const columns = [
        makeColumn('name', t`Name`, "string"),
        {
            Header: t`Color`,
            id: 'color',
            accessor: (model: ShiftModel) => model,
            Cell: (row: { original: ShiftModel | null | undefined }) => {
                return (
                    <Observer>
                        {
                            () => {
                                if (!row.original) {
                                    return null;
                                }
                                return <ShiftColorPicker model={row.original} readOnly={true} includeLabel={false} includeHint={false}/>
                            }
                        }
                    </Observer>
                )
            },
            filterable: false,
            sortable: false,
        }
    ]
    return (
        <BreadModel store={ShiftStore} Form={ShiftForm} columns={columns}/>
    );
});