import React from 'react';
import {PaddedPaper} from "@rx-suite/ui/build";
import {CurrentUserModel, CurrentUserStore} from "@rx-suite/stores/build";
import {observer} from "mobx-react-lite";
import {Container, Grid, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {RxUniverseConnectionButton} from "../components/users/RxUniverseConnectionButton";
import {SignOutFromAllButton} from "../components/profile/SignOutFromAllButton";
import {ProfileSettings} from "./profile/ProfileSettings";

export default observer(() => {
    const user = CurrentUserStore.selectedModel as CurrentUserModel;
    if (!user) {
        return <PaddedPaper>
            <Typography variant={"h5"} gutterBottom>{t`Not signed in`}</Typography>
        </PaddedPaper>;
    }

    return (
        <Container maxWidth={"md"}>
            <Grid container spacing={2}>
                <Grid item xs={12}>
                    <PaddedPaper>
                        <Typography variant={"h3"}>{t`Profile`}</Typography>
                        <Typography variant={"h5"} gutterBottom>{user.name}</Typography>
                        <SignOutFromAllButton/>
                    </PaddedPaper>
                </Grid>
                <Grid item xs={12}>
                    <ProfileSettings />
                </Grid>
                <Grid item xs={12}>
                    <PaddedPaper>
                        <Typography variant={"h3"} gutterBottom>{t`External Connections`}</Typography>
                        <RxUniverseConnectionButton/>
                    </PaddedPaper>
                </Grid>
            </Grid>
        </Container>

    )

});