# == Schema Information
#
# Table name: components
#
#  id                :bigint           not null, primary key
#  description       :string
#  has_token         :boolean
#  ip_address        :string
#  is_api            :boolean
#  is_updating       :boolean
#  last_update_error :string
#  module_name       :string
#  port              :integer
#  protocol          :string           default("http")
#  reachable         :boolean
#  token             :string
#  type              :string
#  update_status     :string
#  version           :string
#  created_at        :datetime         not null
#  updated_at        :datetime         not null
#  email_id          :bigint
#  module_id         :string
#
# Indexes
#
#  index_components_on_email_id             (email_id)
#  index_components_on_module_id            (module_id) UNIQUE
#  index_components_on_port_and_ip_address  (port,ip_address) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (email_id => emails.id) ON DELETE => nullify
#
class MesApiComponent < Component
  before_save :set_module_values

  def set_module_values
    self.module_id = "mes_api"
    self.module_name = "MES API"
    self.description = "Manages Communication with the MES Server"
    self.is_api = true
    self.version = ""
  end

  def ping
    Faraday.get(resolve_endpoint(""))
    update({
      reachable: true
    })
  rescue => err
    Rails.logger.warn { {msg: "Component may be offline or returning invalid responses", component: as_json} }
    update(reachable: false)
  end
end
